@@ -10,6 +10,7 @@ from threadpoolctl import ThreadpoolController
 from threadpoolctl import _ALL_PREFIXES, _ALL_USER_APIS
 
 from .utils import cython_extensions_compiled
+from .utils import check_nested_prange_blas
 from .utils import libopenblas_paths
 from .utils import scipy
 from .utils import threadpool_info_from_subprocess
@@ -406,19 +407,20 @@ def test_multiple_shipped_openblas():
     test_shipped_openblas()
 
 
-@pytest.mark.skipif(scipy is None, reason="requires scipy")
 @pytest.mark.skipif(
     not cython_extensions_compiled, reason="Requires cython extensions to be compiled"
 )
+@pytest.mark.skipif(
+    check_nested_prange_blas is None,
+    reason="Requires nested_prange_blas to be compiled",
+)
 @pytest.mark.parametrize("nthreads_outer", [None, 1, 2, 4])
 def test_nested_prange_blas(nthreads_outer):
-    # Check that the BLAS linked to scipy effectively uses the number of
-    # threads requested by the context manager when nested in an outer OpenMP
-    # loop.
+    # Check that the BLAS uses the number of threads requested by the context manager
+    # when nested in an outer OpenMP loop.
+    # Remark: this test also works with sequential BLAS only because we limit the
+    # number of threads for the BLAS to 1.
     import numpy as np
-    import tests._openmp_test_helper.nested_prange_blas as prange_blas
-
-    check_nested_prange_blas = prange_blas.check_nested_prange_blas
 
     skip_if_openblas_openmp()
 
@@ -545,9 +547,20 @@ def test_libomp_libiomp_warning(recwarn):
     assert "multiple_openmp.md" in str(wm.message)
 
 
-def test_command_line_empty():
+def test_command_line_empty_or_system_openmp():
+    # When the command line is called without arguments, no library should be
+    # detected. The only exception is a system OpenMP library that can be
+    # linked to the Python interpreter, for instance via the libb2.so BLAKE2
+    # library that can itself be linked to an OpenMP runtime on Gentoo.
     output = subprocess.check_output((sys.executable + " -m threadpoolctl").split())
-    assert json.loads(output.decode("utf-8")) == []
+    results = json.loads(output.decode("utf-8"))
+    conda_prefix = os.getenv("CONDA_PREFIX")
+    managed_by_conda = conda_prefix and sys.executable.startswith(conda_prefix)
+    if not managed_by_conda:  # pragma: no cover
+        # When using a Python interpreter that does not come from a conda
+        # environment, we should ignore any system OpenMP library.
+        results = [r for r in results if r["user_api"] != "openmp"]
+    assert results == []
 
 
 def test_command_line_command_flag():
@@ -600,12 +613,12 @@ def test_architecture():
     expected_openblas_architectures = (
         # XXX: add more as needed by CI or developer laptops
         "armv8",
-        "Haswell",
-        "Prescott",  # see: https://github.com/xianyi/OpenBLAS/pull/3485
-        "SkylakeX",
-        "Sandybridge",
-        "VORTEX",
-        "Zen",
+        "haswell",
+        "prescott",  # see: https://github.com/xianyi/OpenBLAS/pull/3485
+        "skylakex",
+        "sandybridge",
+        "vortex",
+        "zen",
     )
     expected_blis_architectures = (
         # XXX: add more as needed by CI or developer laptops
@@ -614,9 +627,9 @@ def test_architecture():
     )
     for lib_info in threadpool_info():
         if lib_info["internal_api"] == "openblas":
-            assert lib_info["architecture"] in expected_openblas_architectures
+            assert lib_info["architecture"].lower() in expected_openblas_architectures
         elif lib_info["internal_api"] == "blis":
-            assert lib_info["architecture"] in expected_blis_architectures
+            assert lib_info["architecture"].lower() in expected_blis_architectures
         else:
             # Not supported for other libraries
             assert "architecture" not in lib_info
@@ -641,6 +654,81 @@ def test_openblas_threading_layer():
     assert threading_layer in expected_openblas_threading_layers
 
 
+# skip test if not run in a azure pipelines job since it relies on a specific flexiblas
+# installation.
+@pytest.mark.skipif(
+    "TF_BUILD" not in os.environ, reason="not running in azure pipelines"
+)
+def test_flexiblas():
+    # Check that threadpool_info correctly recovers the FlexiBLAS backends.
+    flexiblas_controller = ThreadpoolController().select(internal_api="flexiblas")
+
+    if not flexiblas_controller:
+        pytest.skip("requires FlexiBLAS.")
+    flexiblas_controller = flexiblas_controller.lib_controllers[0]
+
+    expected_backends = {"NETLIB", "OPENBLAS_CONDA"}
+    expected_backends_loaded = {"OPENBLAS_CONDA"}
+    expected_current_backend = "OPENBLAS_CONDA"  # set as default at build time
+
+    flexiblas_backends = flexiblas_controller.available_backends
+    flexiblas_backends_loaded = flexiblas_controller.loaded_backends
+    current_backend = flexiblas_controller.current_backend
+
+    assert set(flexiblas_backends) == expected_backends
+    assert set(flexiblas_backends_loaded) == expected_backends_loaded
+    assert current_backend == expected_current_backend
+
+
+def test_flexiblas_switch_error():
+    # Check that an error is raised when trying to switch to an invalid backend.
+    flexiblas_controller = ThreadpoolController().select(internal_api="flexiblas")
+
+    if not flexiblas_controller:
+        pytest.skip("requires FlexiBLAS.")
+    flexiblas_controller = flexiblas_controller.lib_controllers[0]
+
+    with pytest.raises(RuntimeError, match="Failed to load backend"):
+        flexiblas_controller.switch_backend("INVALID_BACKEND")
+
+
+# skip test if not run in a azure pipelines job since it relies on a specific flexiblas
+# installation.
+@pytest.mark.skipif(
+    "TF_BUILD" not in os.environ, reason="not running in azure pipelines"
+)
+def test_flexiblas_switch():
+    # Check that the backend can be switched.
+    controller = ThreadpoolController()
+    fb_controller = controller.select(internal_api="flexiblas")
+
+    if not fb_controller:
+        pytest.skip("requires FlexiBLAS.")
+    fb_controller = fb_controller.lib_controllers[0]
+
+    # at first mkl is not loaded in the CI jobs where this test runs
+    assert len(controller.select(internal_api="mkl").lib_controllers) == 0
+
+    # at first, only "OPENBLAS_CONDA" is loaded
+    assert fb_controller.current_backend == "OPENBLAS_CONDA"
+    assert fb_controller.loaded_backends == ["OPENBLAS_CONDA"]
+
+    fb_controller.switch_backend("NETLIB")
+    assert fb_controller.current_backend == "NETLIB"
+    assert fb_controller.loaded_backends == ["OPENBLAS_CONDA", "NETLIB"]
+
+    ext = ".so" if sys.platform == "linux" else ".dylib"
+    mkl_path = f"{os.getenv('CONDA_PREFIX')}/lib/libmkl_rt{ext}"
+    fb_controller.switch_backend(mkl_path)
+    assert fb_controller.current_backend == mkl_path
+    assert fb_controller.loaded_backends == ["OPENBLAS_CONDA", "NETLIB", mkl_path]
+    # switching the backend triggered a new search for loaded shared libs
+    assert len(controller.select(internal_api="mkl").lib_controllers) == 1
+
+    # switch back to default to avoid side effects
+    fb_controller.switch_backend("OPENBLAS_CONDA")
+
+
 def test_threadpool_controller_as_decorator():
     # Check that using the decorator can be nested and is restricted to the scope of
     # the decorated function.
